﻿namespace TaskPlanner.BusinessLogic.Interfaces
{
	using System.Collections.ObjectModel;
	using TaskPlanner.Entities;

	/// <summary>
	/// The interface for availability managers.
	/// </summary>
	public interface IAvailabilityManager
	{
		#region Methods
		/// <summary>
		/// Gets the usual availabilities.
		/// </summary>
		/// <returns>Usual availabilities by days of week.</returns>
		Collection<UsualAvailability> GetUsualAvailabilities();

		/// <summary>
		/// Sets the usual availabilities.
		/// </summary>
		/// <param name="usualAvailabilities">The usual availabilities by days of week.</param>
		void SetUsualAvailabilities(Collection<UsualAvailability> usualAvailabilities);

		/// <summary>
		/// Gets the specific availabilities.
		/// </summary>
		/// <returns>Specific availabilities.</returns>
		Collection<SpecificAvailability> GetSpecificAvailabilities();

		/// <summary>
		/// Adds the specific availability.
		/// </summary>
		/// <param name="specificAvailability">The specific availability.</param>
		void AddSpecificAvailability(SpecificAvailability specificAvailability);

		/// <summary>
		/// Creates the specific availability.
		/// </summary>
		/// <returns>The new specific availability.</returns>
		SpecificAvailability CreateSpecificAvailability();
		#endregion
	}
}
