﻿namespace TaskPlanner.BusinessLogic.Interfaces
{
	using System;
	using System.Collections.ObjectModel;
	using TaskPlanner.Entities;

	/// <summary>
	/// Represents interface for task managers.
	/// </summary>
	public interface ITaskManager
	{
		#region Events
		/// <summary>
		/// Occurs when task is changed.
		/// </summary>
		event EventHandler<TaskCorrectionRequestedEventArgs> TaskCorrectionsRequested;
		#endregion

		#region Methods
		/// <summary>
		/// Saves the task.
		/// </summary>
		/// <param name="task">The task to be saved.</param>
		void SaveTask(Task task);

		/// <summary>
		/// Gets all tasks.
		/// </summary>
		/// <returns>The all tasks in repository.</returns>
		Collection<Task> GetAllTasks();

		/// <summary>
		/// Gets the topmost level tasks and assigns their children recursively.
		/// </summary>
		/// <returns>Tasks tree.</returns>
		Collection<Task> GetTasksTree();

		/// <summary>
		/// Creates the new task.
		/// </summary>
		/// <returns>Task with prefilled fields.</returns>
		Task CreateNewTask();

		/// <summary>
		/// Corrects task due to estimated time change.
		/// </summary>
		/// <param name="task">The task to be corrected.</param>
		/// <param name="isDueDateEdited">If set to <c>true</c> it means that due date was edited.</param>
		/// <returns>Task correction result.</returns>
		TaskCorrectionResult ApplyEstimatedTimeChange(Task task, bool isDueDateEdited);

		/// <summary>
		/// Correctes the task due to completed percentage change.
		/// </summary>
		/// <param name="task">The task to be corrected.</param>
		/// <returns>Task correction result.</returns>
		TaskCorrectionResult ApplyCompletedPercentageChange(Task task);

		/// <summary>
		/// Corrects the task due to completed time change.
		/// </summary>
		/// <param name="task">The task to be corrected.</param>
		/// <returns>Task correction result.</returns>
		TaskCorrectionResult ApplyCompletedTimeChange(Task task);

		/// <summary>
		/// Validates all tasks.
		/// </summary>
		void ValidateAllTasks();

		/// <summary>
		/// Deletes the sepcified task.
		/// </summary>
		/// <param name="task">The task to be deleted.</param>
		void DeleteTask(Task task);
		#endregion
	}
}
