﻿namespace TaskPlanner.BusinessLogic.Test
{
	using System;
	using System.Collections.ObjectModel;
	using Microsoft.VisualStudio.TestTools.UnitTesting;
	using TaskPlanner.BusinessLogic;
	using TaskPlanner.BusinessLogic.Test.Mocks;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;

	/// <summary>
	/// This is a test class for AvailabilityManagerTest and is intended
	/// to contain all AvailabilityManagerTest Unit Tests.
	/// </summary>
	[TestClass()]
	public class AvailabilityManagerTest
	{
		#region Fields
		private TestContext _testContextInstance;
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the test context which provides
		/// information about and functionality for the current test run.
		/// </summary>
		/// <value>The test context.</value>
		public TestContext TestContext
		{
			get
			{
				return _testContextInstance;
			}

			set
			{
				_testContextInstance = value;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// A test for GetUsualAvailabilities.
		/// </summary>
		[TestMethod()]
		public void GetUsualAvailabilitiesTest()
		{
			UsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			SpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			AvailabilityManager target = new AvailabilityManager(usualAvailabilityRepository, specificAvailabilityRepository);
			target.GetUsualAvailabilities();
			Assert.IsTrue(usualAvailabilityRepository.IsGetUsualAvailabilitiesCalled);
		}

		/// <summary>
		/// A test for AvailabilityManager Constructor.
		/// </summary>
		[TestMethod()]
		public void AvailabilityManagerConstructorTest()
		{
			IUsualAvailabilityRepository nullUsualAvailabilityRepository = null;
			ISpecificAvailabilityRepository nullSpecificAvailabilityRepository = null;
			IUsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			ISpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			Utils.AssertException(
				() => new AvailabilityManager(nullUsualAvailabilityRepository, nullSpecificAvailabilityRepository),
				typeof(ArgumentNullException));
			Utils.AssertException(
				() => new AvailabilityManager(nullUsualAvailabilityRepository, specificAvailabilityRepository),
				typeof(ArgumentNullException));
			Utils.AssertException(
				() => new AvailabilityManager(usualAvailabilityRepository, nullSpecificAvailabilityRepository),
				typeof(ArgumentNullException));
		}

		/// <summary>
		/// A test for SetUsualAvailabilities.
		/// </summary>
		[TestMethod()]
		public void SetUsualAvailabilitiesTest()
		{
			UsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			SpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			AvailabilityManager target = new AvailabilityManager(usualAvailabilityRepository, specificAvailabilityRepository);
			Utils.AssertException(() => target.SetUsualAvailabilities(null), typeof(ArgumentNullException));
			target.SetUsualAvailabilities(new Collection<UsualAvailability>());
			Assert.IsTrue(usualAvailabilityRepository.IsSetUsualAvailabilitiesCalled);
		}

		/// <summary>
		/// A test for GetSpecificAvailabilities.
		/// </summary>
		[TestMethod()]
		public void GetSpecificAvailabilitiesTest()
		{
			IUsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			SpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			AvailabilityManager target = new AvailabilityManager(usualAvailabilityRepository, specificAvailabilityRepository);
			target.GetSpecificAvailabilities();
			Assert.IsTrue(specificAvailabilityRepository.IsGetAvailabiliesCalled);
		}

		/// <summary>
		/// A test for AddSpecificAvailability.
		/// </summary>
		[TestMethod()]
		public void AddSpecificAvailabilityTest()
		{
			IUsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			SpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			AvailabilityManager target = new AvailabilityManager(usualAvailabilityRepository, specificAvailabilityRepository);
			Utils.AssertException(() => target.AddSpecificAvailability(null), typeof(ArgumentNullException));
			SpecificAvailability availability = new SpecificAvailability();
			target.AddSpecificAvailability(availability);
			Assert.IsTrue(specificAvailabilityRepository.IsAddAvailabilityCalled);
		}

		/// <summary>
		/// A test for CreateSpecificAvailability.
		/// </summary>
		[TestMethod()]
		public void CreateSpecificAvailabilityTest()
		{
			IUsualAvailabilityRepository usualAvailabilityRepository = new UsualAvailabilityRepository();
			ISpecificAvailabilityRepository specificAvailabilityRepository = new SpecificAvailabilityRepository();
			AvailabilityManager target = new AvailabilityManager(usualAvailabilityRepository, specificAvailabilityRepository);
			SpecificAvailability actual = target.CreateSpecificAvailability();
			Assert.IsNotNull(actual);
		}
		#endregion
	}
}
