﻿namespace TaskPlanner.BusinessLogic.Test.Mocks
{
	using System;
	using System.Collections.ObjectModel;
	using System.Linq;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;

	/// <summary>
	/// Represents a mock for ISpecificAvailabilityRepository.
	/// </summary>
	internal class SpecificAvailabilityRepository : ISpecificAvailabilityRepository
	{
		#region Fields
		private bool _isGetAvailabilitiesCalled;
		private bool _isAddAvailabilityCalled;
		private Collection<SpecificAvailability> _storage;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="SpecificAvailabilityRepository"/> class.
		/// </summary>
		internal SpecificAvailabilityRepository()
		{
			_storage = new Collection<SpecificAvailability>();
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets a value indicating whether this instance is get availabilies called.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if this instance is get availabilies called; otherwise, <c>false</c>.
		/// </value>
		internal bool IsGetAvailabiliesCalled
		{
			get
			{
				return _isGetAvailabilitiesCalled;
			}
		}

		/// <summary>
		/// Gets a value indicating whether this instance is add availability called.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if this instance is add availability called; otherwise, <c>false</c>.
		/// </value>
		internal bool IsAddAvailabilityCalled
		{
			get
			{
				return _isAddAvailabilityCalled;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Gets the availabilities.
		/// </summary>
		/// <param name="startDate">The start date.</param>
		/// <returns>
		/// The list of specific availabilities in specified date range.
		/// </returns>
		public Collection<SpecificAvailability> GetAvailabilities(DateTime startDate)
		{
			_isGetAvailabilitiesCalled = true;
			return new Collection<SpecificAvailability>(
				(from item in _storage
				 where item.Date >= startDate
				 select item).ToList());
		}

		/// <summary>
		/// Saves the availability.
		/// </summary>
		/// <param name="availability">The availability.</param>
		public void AddAvailability(SpecificAvailability availability)
		{
			_isAddAvailabilityCalled = true;
			SpecificAvailability existingAvailability =
				(from item in _storage
				 where item.Date == availability.Date
				 select item).SingleOrDefault();
			if (existingAvailability == null)
			{
				_storage.Add(availability);
			}
			else
			{
				existingAvailability.Availability = availability.Availability;
			}
		}
		#endregion
	}
}
