﻿namespace TaskPlanner.BusinessLogic.Test.Mocks
{
	using System.Collections.ObjectModel;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;

	/// <summary>
	/// Represents a mock for IUsualAvailabilityRepository.
	/// </summary>
	internal class UsualAvailabilityRepository : IUsualAvailabilityRepository
	{
		#region Fields
		private bool _isGetUsualAvailabilitiesCalled;
		private bool _isSetUsualAvailabilitiesCalled;
		#endregion

		#region Properties
		/// <summary>
		/// Gets a value indicating whether method GetUsualAvailabilities was called.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if method GetUsualAvailabilities was called; otherwise, <c>false</c>.
		/// </value>
		internal bool IsGetUsualAvailabilitiesCalled
		{
			get
			{
				return _isGetUsualAvailabilitiesCalled;
			}
		}

		/// <summary>
		/// Gets a value indicating whether method SetUsualAvailabilities was called.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if method SetUsualAvailabilities was called; otherwise, <c>false</c>.
		/// </value>
		internal bool IsSetUsualAvailabilitiesCalled
		{
			get
			{
				return _isSetUsualAvailabilitiesCalled;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Gets the usual availabilities.
		/// </summary>
		/// <returns>Usual availabilities by days of week.</returns>
		public Collection<UsualAvailability> GetUsualAvailabilities()
		{
			_isGetUsualAvailabilitiesCalled = true;
			return new Collection<UsualAvailability>();
		}

		/// <summary>
		/// Sets the usual availabilities.
		/// </summary>
		/// <param name="usualAvailabilities">The usual availabilities by days of week.</param>
		public void SetUsualAvailabilities(Collection<UsualAvailability> usualAvailabilities)
		{
			_isSetUsualAvailabilitiesCalled = true;
		}

		#endregion
	}
}
