﻿namespace TaskPlanner.BusinessLogic
{
	using System;
	using System.Collections.ObjectModel;
	using TaskPlanner.BusinessLogic.Interfaces;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;

	/// <summary>
	/// Represents class which helps to perform operations with availability.
	/// </summary>
	public class AvailabilityManager : IAvailabilityManager
	{
		#region Fields
		private IUsualAvailabilityRepository _usualAvailabilityRepository;
		private ISpecificAvailabilityRepository _specificAvailabilityRepository;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="AvailabilityManager"/> class.
		/// </summary>
		/// <param name="usualAvailabilityRepository">The usual availability repository.</param>
		/// <param name="specificAvailabilityRepository">The specific availability repository.</param>
		public AvailabilityManager(IUsualAvailabilityRepository usualAvailabilityRepository, ISpecificAvailabilityRepository specificAvailabilityRepository)
		{
			if (usualAvailabilityRepository == null)
			{
				throw new ArgumentNullException("usualAvailabilityRepository");
			}
			if (specificAvailabilityRepository == null)
			{
				throw new ArgumentNullException("specificAvailabilityRepository");
			}
			_usualAvailabilityRepository = usualAvailabilityRepository;
			_specificAvailabilityRepository = specificAvailabilityRepository;
		}
		#endregion

		#region Methods
		/// <summary>
		/// Gets the usual availabilities.
		/// </summary>
		/// <returns>Usual availabilities by days of week.</returns>
		public Collection<UsualAvailability> GetUsualAvailabilities()
		{
			return _usualAvailabilityRepository.GetUsualAvailabilities();
		}

		/// <summary>
		/// Sets the usual availabilities.
		/// </summary>
		/// <param name="usualAvailabilities">The usual availabilities by days of week.</param>
		public void SetUsualAvailabilities(Collection<UsualAvailability> usualAvailabilities)
		{
			if (usualAvailabilities == null)
			{
				throw new ArgumentNullException("usualAvailabilities");
			}
			_usualAvailabilityRepository.SetUsualAvailabilities(usualAvailabilities);
		}

		/// <summary>
		/// Gets the specific availabilities.
		/// </summary>
		/// <returns>Specific availabilities.</returns>
		public Collection<SpecificAvailability> GetSpecificAvailabilities()
		{
			return _specificAvailabilityRepository.GetAvailabilities(DateTime.Today);
		}

		/// <summary>
		/// Adds the specific availability.
		/// </summary>
		/// <param name="specificAvailability">The specific availability.</param>
		public void AddSpecificAvailability(SpecificAvailability specificAvailability)
		{
			if (specificAvailability == null)
			{
				throw new ArgumentNullException("specificAvailability");
			}
			_specificAvailabilityRepository.AddAvailability(specificAvailability);
		}

		/// <summary>
		/// Creates the specific availability.
		/// </summary>
		/// <returns>The new specific availability.</returns>
		public SpecificAvailability CreateSpecificAvailability()
		{
			SpecificAvailability result = new SpecificAvailability();
			return result;
		}
		#endregion
	}
}
