﻿namespace TaskPlanner.Core
{
	using System;
	using System.Diagnostics;
	using Microsoft.Practices.EnterpriseLibrary.Logging;

	/// <summary>
	/// Represents the helper class to write logs.
	/// </summary>
	public class LogHelper : ILogHelper
	{
		#region Fields
		private LogWriter _logWriter;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="LogHelper"/> class.
		/// </summary>
		/// <param name="logWriter">The log writer.</param>
		public LogHelper(LogWriter logWriter)
		{
			_logWriter = logWriter;
		}
		#endregion

		#region Methods
		/// <summary>
		/// Writes the error.
		/// </summary>
		/// <param name="ex">The exception.</param>
		public void WriteError(Exception ex)
		{
			if (ex == null)
			{
				throw new ArgumentNullException("ex");
			}
			if (_logWriter.IsLoggingEnabled())
			{
				LogEntry entry = new LogEntry();
				entry.Message = ex.ToString();
				entry.Severity = TraceEventType.Error;
				_logWriter.Write(entry);
			}
		}

		/// <summary>
		/// Writes the info.
		/// </summary>
		/// <param name="message">The message.</param>
		public void WriteInfo(string message)
		{
			if (_logWriter.IsLoggingEnabled())
			{
				LogEntry entry = new LogEntry();
				entry.Message = message;
				entry.Severity = TraceEventType.Information;
				_logWriter.Write(entry);
			}
		}

		/// <summary>
		/// Writes the info.
		/// </summary>
		/// <param name="provider">The provider.</param>
		/// <param name="format">The format.</param>
		/// <param name="args">The arguments.</param>
		public void WriteInfo(IFormatProvider provider, string format, params object[] args)
		{
			WriteInfo(string.Format(provider, format, args));
		}
		#endregion
	}
}
