﻿namespace TaskPlanner.Core
{
	using System;
	using System.Collections.Generic;
	using System.Globalization;
	using Microsoft.Practices.Unity.InterceptionExtension;

	/// <summary>
	/// Represents an interception behavior for logging.
	/// </summary>
	public class LoggingBehavior : IInterceptionBehavior
	{
		#region Properties
		/// <summary>
		/// Gets a value indicating whether this behavior will actually
		/// perform any operations when invoked.
		/// </summary>
		/// <value>Info whether this behavior will actually perform any operation.</value>
		public bool WillExecute
		{
			get
			{
				return true;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Invokes the specified method.
		/// </summary>
		/// <param name="input">The method details.</param>
		/// <param name="getNext">The delegate to get next behavior in a chain.</param>
		/// <returns>The inoked method result.</returns>
		public IMethodReturn Invoke(IMethodInvocation input, GetNextInterceptionBehaviorDelegate getNext)
		{
			if (input == null)
			{
				throw new ArgumentNullException("input");
			}
			if (getNext == null)
			{
				throw new ArgumentNullException("getNext");
			}
			ILogHelper logger = ServiceLocator.Instance.Resolve<ILogHelper>();
			logger.WriteInfo(string.Format(
				CultureInfo.InvariantCulture,
				"The invokation of method '{0}.{1}' is started.",
				input.MethodBase.ReflectedType.FullName,
				input.MethodBase.Name));
			IMethodReturn result = getNext()(input, getNext);
			logger.WriteInfo(string.Format(
				CultureInfo.InvariantCulture,
				"The invokation of method '{0}.{1}' is completed.",
				input.MethodBase.ReflectedType.FullName,
				input.MethodBase.Name));
			return result;
		}

		/// <summary>
		/// Returns the interfaces required by the behavior for the objects it intercepts.
		/// </summary>
		/// <returns>
		/// The required interfaces.
		/// </returns>
		public IEnumerable<Type> GetRequiredInterfaces()
		{
			return new List<Type>();
		}
		#endregion
	}
}
