﻿namespace TaskPlanner.Entities
{
	using System;
	using System.Collections.ObjectModel;

	/// <summary>
	/// The task to be operated with.
	/// </summary>
	public class Task : DataObject<Guid>
	{
		#region Fields
		private string _category;
		private Collection<Task> _children;
		private int _completedPercentage;
		private float _completedTime;
		private DateTime _dueDate;
		private DateTime _endDate;
		private float _estimatedTime;
		private Task _parent;
		private Guid? _parentId;
		private DateTime _startDate;
		private string _taskName;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="Task"/> class.
		/// </summary>
		public Task()
		{
			_children = new Collection<Task>();
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the category.
		/// </summary>
		/// <value>The category.</value>
		public string Category
		{
			get
			{
				return _category;
			}

			set
			{
				_category = value;
			}
		}

		/// <summary>
		/// Gets the children.
		/// </summary>
		/// <value>The children.</value>
		public Collection<Task> Children
		{
			get
			{
				return _children;
			}
		}

		/// <summary>
		/// Gets or sets the completed percentage.
		/// </summary>
		/// <value>The completed percentage.</value>
		public int CompletedPercentage
		{
			get
			{
				return _completedPercentage;
			}

			set
			{
				_completedPercentage = value;
			}
		}

		/// <summary>
		/// Gets or sets the completed time.
		/// </summary>
		/// <value>The completed time.</value>
		public float CompletedTime
		{
			get
			{
				return _completedTime;
			}

			set
			{
				_completedTime = value;
			}
		}

		/// <summary>
		/// Gets or sets the due date.
		/// </summary>
		/// <value>The due date.</value>
		public DateTime DueDate
		{
			get
			{
				return _dueDate;
			}

			set
			{
				_dueDate = value;
			}
		}

		/// <summary>
		/// Gets or sets the end date.
		/// </summary>
		/// <value>The end date.</value>
		public DateTime EndDate
		{
			get
			{
				return _endDate;
			}

			set
			{
				_endDate = value;
			}
		}

		/// <summary>
		/// Gets or sets the estimated time.
		/// </summary>
		/// <value>The estimated time.</value>
		public float EstimatedTime
		{
			get
			{
				return _estimatedTime;
			}

			set
			{
				_estimatedTime = value;
			}
		}

		/// <summary>
		/// Gets or sets the parent.
		/// </summary>
		/// <value>The parent.</value>
		public Task Parent
		{
			get
			{
				return _parent;
			}

			set
			{
				_parent = value;
			}
		}

		/// <summary>
		/// Gets or sets the parent ID.
		/// </summary>
		/// <value>The parent ID.</value>
		public Guid? ParentId
		{
			get
			{
				return _parentId;
			}

			set
			{
				_parentId = value;
			}
		}

		/// <summary>
		/// Gets or sets the start date.
		/// </summary>
		/// <value>The start date.</value>
		public DateTime StartDate
		{
			get
			{
				return _startDate;
			}

			set
			{
				_startDate = value;
			}
		}

		/// <summary>
		/// Gets or sets the name of the task.
		/// </summary>
		/// <value>The name of the task.</value>
		public string TaskName
		{
			get
			{
				return _taskName;
			}

			set
			{
				_taskName = value;
			}
		}
		#endregion

		#region Methdos
		/// <summary>
		/// Clones this instance.
		/// </summary>
		/// <returns>The shallow copy of this object.</returns>
		public Task Clone()
		{
			Task result = new Task();
			result.Category = Category;
			result.CompletedPercentage = CompletedPercentage;
			result.CompletedTime = CompletedTime;
			result.DueDate = DueDate;
			result.EndDate = EndDate;
			result.EstimatedTime = EstimatedTime;
			result.ParentId = ParentId;
			result.StartDate = StartDate;
			result.TaskName = TaskName;
			return result;
		}

		/// <summary>
		/// Returns a <see cref="System.String"/> that represents this instance.
		/// </summary>
		/// <returns>
		/// A <see cref="System.String"/> that represents this instance.
		/// </returns>
		public override string ToString()
		{
			return TaskName;
		}
		#endregion
	}
}
