﻿namespace TaskPlanner.Entities
{
	/// <summary>
	/// Represents the result of correction of task.
	/// </summary>
	public class TaskCorrectionResult
	{
		#region Fields
		private Task _correctedTask;
		private bool _isCorrectionMade;
		private TaskCorrectionReason _correctionReason;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="TaskCorrectionResult"/> class.
		/// </summary>
		public TaskCorrectionResult()
		{
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="TaskCorrectionResult"/> class.
		/// </summary>
		/// <param name="correctedTask">The corrected task.</param>
		/// <param name="correctionReason">The correction reason.</param>
		public TaskCorrectionResult(Task correctedTask, TaskCorrectionReason correctionReason)
		{
			_correctedTask = correctedTask;
			_isCorrectionMade = true;
			_correctionReason = correctionReason;
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the corrected task.
		/// </summary>
		/// <value>The corrected task.</value>
		public Task CorrectedTask
		{
			get
			{
				return _correctedTask;
			}

			set
			{
				_correctedTask = value;
			}
		}

		/// <summary>
		/// Gets or sets a value indicating whether correction is made.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if correction is made; otherwise, <c>false</c>.
		/// </value>
		public bool IsCorrectionMade
		{
			get
			{
				return _isCorrectionMade;
			}

			set
			{
				_isCorrectionMade = value;
			}
		}

		/// <summary>
		/// Gets or sets the correction reason.
		/// </summary>
		/// <value>The correction reason.</value>
		public TaskCorrectionReason CorrectionReason
		{
			get
			{
				return _correctionReason;
			}

			set
			{
				_correctionReason = value;
			}
		}
		#endregion
	}
}
