﻿namespace TaskPlanner.Repository.Interfaces
{
	using System;
	using System.Collections.ObjectModel;
	using System.Linq.Expressions;
	using TaskPlanner.Entities;

	/// <summary>
	/// Interface for task repositories.
	/// </summary>
	public interface ITaskRepository
	{
		#region Methods
		/// <summary>
		/// Gets all tasks.
		/// </summary>
		/// <returns>The all tasks in repository.</returns>
		Collection<Task> GetAllTasks();

		/// <summary>
		/// Gets the topmost level tasks and assigns their children recursively.
		/// </summary>
		/// <returns>Tasks tree.</returns>
		Collection<Task> GetTasksTree();

		/// <summary>
		/// Gets the active tasks.
		/// </summary>
		/// <typeparam name="TOrder">The type of the order.</typeparam>
		/// <param name="filter">The filter.</param>
		/// <param name="order">The order.</param>
		/// <returns>Active tasks.</returns>
		Collection<Task> GetActiveTasks<TOrder>(
			Expression<Func<Task, bool>> filter,
			Expression<Func<Task, TOrder>> order);

		/// <summary>
		/// Gets the active tasks.
		/// </summary>
		/// <typeparam name="TOrder">The type of the order.</typeparam>
		/// <param name="order">The order.</param>
		/// <returns>Active tasks in specified order.</returns>
		Collection<Task> GetActiveTasks<TOrder>(Expression<Func<Task, TOrder>> order);

		/// <summary>
		/// Saves the task.
		/// </summary>
		/// <param name="task">The task to be saved.</param>
		void SaveTask(Task task);

		/// <summary>
		/// Deletes the task.
		/// </summary>
		/// <param name="task">The task to be deleted.</param>
		void DeleteTask(Task task);
		#endregion
	}
}
