﻿namespace TaskPlanner.Repository.Test
{
	using System;
	using System.Collections.ObjectModel;
	using System.IO;
	using System.Linq;
	using Microsoft.VisualStudio.TestTools.UnitTesting;
	using TaskPlanner.Entities;

	/// <summary>
	/// This is a test class for CategoryRepositoryTest and is intended
	/// to contain all CategoryRepositoryTest Unit Tests.
	/// </summary>
	[TestClass()]
	public class CategoryRepositoryTest
	{
		#region Fields
		private TestContext _testContextInstance;
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the test context which provides
		/// information about and functionality for the current test run.
		/// </summary>
		/// <value>The test context.</value>
		public TestContext TestContext
		{
			get
			{
				return _testContextInstance;
			}

			set
			{
				_testContextInstance = value;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Initializes the every test.
		/// </summary>
		[TestInitialize]
		public void InitializeTest()
		{
			if (File.Exists(Utils.DataSource))
			{
				File.Delete(Utils.DataSource);
			}
			DataHelper dataHelper = new DataHelper(new TestsLogHelper());
			dataHelper.EnsureDatabaseHasLatestSchema();
		}

		/// <summary>
		/// A test for GetAllCategories.
		/// </summary>
		[TestMethod()]
		public void GetAllCategoriesTest()
		{
			TaskRepository taskRepository = new TaskRepository();
			Task task = new Task();
			task.Id = Guid.NewGuid();
			string expectedTaskName = Guid.NewGuid().ToString();
			task.TaskName = expectedTaskName;
			task.StartDate = DateTime.Today;
			task.EndDate = DateTime.Today;
			task.DueDate = DateTime.Today;
			task.Category = Guid.NewGuid().ToString();
			taskRepository.SaveTask(task);
			CategoryRepository target = new CategoryRepository();
			Collection<string> expected = new Collection<string>();
			expected.Add(task.Category);
			Collection<string> actual;
			actual = target.GetAllCategories();
			Assert.AreEqual(expected.Count, actual.Count);
			Assert.AreEqual(expected.First(), actual.First());
		}

		/// <summary>
		/// A test for CategoryRepository Constructor.
		/// </summary>
		[TestMethod()]
		public void CategoryRepositoryConstructorTest()
		{
			CategoryRepository target = new CategoryRepository(); // Just to ensure that there is no exceptions.
		}
		#endregion
	}
}
