﻿namespace TaskPlanner.Repository.Test
{
	using System;
	using System.Collections.ObjectModel;
	using System.IO;
	using System.Linq;
	using Microsoft.VisualStudio.TestTools.UnitTesting;
	using TaskPlanner.Entities;

	/// <summary>
	/// This is a test class for SpecificAvailabilityRepositoryTest and is intended
	/// to contain all SpecificAvailabilityRepositoryTest Unit Tests.
	/// </summary>
	[TestClass()]
	public class SpecificAvailabilityRepositoryTest
	{
		#region Fields
		private TestContext _testContextInstance;
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the test context which provides
		/// information about and functionality for the current test run.
		/// </summary>
		/// <value>The test context.</value>
		public TestContext TestContext
		{
			get
			{
				return _testContextInstance;
			}

			set
			{
				_testContextInstance = value;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Initializes the every test.
		/// </summary>
		[TestInitialize]
		public void InitializeTest()
		{
			if (File.Exists(Utils.DataSource))
			{
				File.Delete(Utils.DataSource);
			}
			DataHelper dataHelper = new DataHelper(new TestsLogHelper());
			dataHelper.EnsureDatabaseHasLatestSchema();
		}

		/// <summary>
		/// A test for SpecificAvailabilityRepository Constructor.
		/// </summary>
		[TestMethod()]
		public void SpecificAvailabilityRepositoryConstructorTest()
		{
			SpecificAvailabilityRepository target = new SpecificAvailabilityRepository(); // Just to verify that there is no exceptions.
		}

		/// <summary>
		/// A test for GetAvailabilities.
		/// </summary>
		[TestMethod()]
		public void GetAvailabilitiesTest()
		{
			SpecificAvailabilityRepository target = new SpecificAvailabilityRepository();
			Utils.AssertException(() => target.AddAvailability(null), typeof(ArgumentNullException));
			float expectedAvailability = 3;
			DateTime expectedDate = DateTime.Today;
			SpecificAvailability availability = new SpecificAvailability();
			availability.Availability = expectedAvailability;
			availability.Date = expectedDate;
			target.AddAvailability(availability);
			availability = new SpecificAvailability();
			availability.Availability = 5;
			availability.Date = expectedDate.AddDays(1);
			target.AddAvailability(availability);
			Collection<SpecificAvailability> availabilities = target.GetAvailabilities(DateTime.Today.AddDays(-30));
			Assert.AreEqual(2, availabilities.Count);
			SpecificAvailability availabilityFromDatabase =
				(from item in availabilities
				 where item.Date == expectedDate
				 select item).Single();
			Assert.AreEqual(expectedDate, availabilityFromDatabase.Date);
			Assert.AreEqual(expectedAvailability, availabilityFromDatabase.Availability);
		}

		/// <summary>
		/// A test for SaveAvailability.
		/// </summary>
		[TestMethod()]
		public void SaveAvailabilityTest()
		{
			SpecificAvailabilityRepository target = new SpecificAvailabilityRepository();
			float expectedAvailability = 3;
			DateTime expectedDate = DateTime.Today;
			SpecificAvailability availability = new SpecificAvailability();
			availability.Availability = expectedAvailability;
			availability.Date = DateTime.Now;
			target.AddAvailability(availability);
			Collection<SpecificAvailability> availabilities = target.GetAvailabilities(DateTime.Today.AddDays(-30));
			SpecificAvailability availabilityFromDatabase =
				(from item in availabilities
				 where item.Date == expectedDate
				 select item).Single();
			Assert.AreEqual(expectedDate, availabilityFromDatabase.Date);
			Assert.AreEqual(expectedAvailability, availabilityFromDatabase.Availability);
			availability = new SpecificAvailability();
			expectedAvailability++;
			availability.Availability = expectedAvailability;
			availability.Date = expectedDate;
			target.AddAvailability(availability);
			availabilities = target.GetAvailabilities(DateTime.Today.AddDays(-30));
			Assert.AreEqual(1, availabilities.Count);
			availabilityFromDatabase =
				(from item in availabilities
				 where item.Date == expectedDate
				 select item).Single();
			Assert.AreEqual(expectedDate, availabilityFromDatabase.Date);
			Assert.AreEqual(expectedAvailability, availabilityFromDatabase.Availability);
		}
		#endregion
	}
}
