﻿namespace TaskPlanner.Repository.Test
{
	using System;
	using System.Data.SqlServerCe;
	using System.Globalization;
	using System.Linq;
	using Microsoft.VisualStudio.TestTools.UnitTesting;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Model;

	/// <summary>
	/// This is a test class for TaskPlannerDataContextTest and is intended
	/// to contain all TaskPlannerDataContextTest Unit Tests.
	/// </summary>
	[TestClass()]
	public class TaskPlannerDataContextTest
	{
		#region Fields
		private TestContext _testContextInstance;
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the test context which provides
		/// information about and functionality for the current test run.
		/// </summary>
		/// <value>The test context.</value>
		public TestContext TestContext
		{
			get
			{
				return _testContextInstance;
			}

			set
			{
				_testContextInstance = value;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// A test for TaskPlannerDataContext Constructor.
		/// </summary>
		[TestMethod()]
		public void TaskPlannerDataContextConstructorTest()
		{
			TaskPlannerDataContext target = new TaskPlannerDataContext(); // Just to verify there is no exceptions.
		}

		/// <summary>
		/// A test for DatabaseConfigurations.
		/// </summary>
		[TestMethod()]
		public void DatabaseConfigurationsTest()
		{
			DataHelper_Accessor dataHelper = new DataHelper_Accessor(new TestsLogHelper());
			dataHelper.UpdateDatabaseSchema();
			string propertyName = Guid.NewGuid().ToString();
			string expectedPropertyValue = Guid.NewGuid().ToString();
			using (SqlCeConnection connection = Utils.CreateConnection())
			{
				using (SqlCeCommand command = connection.CreateCommand())
				{
					command.CommandText = string.Format(
						CultureInfo.InvariantCulture,
						"INSERT INTO DatabaseConfiguration (PropertyName, PropertyValue) VALUES ('{0}', '{1}')",
						propertyName,
						expectedPropertyValue);
					connection.Open();
					command.ExecuteNonQuery();
				}
			}
			TaskPlannerDataContext target = new TaskPlannerDataContext();
			DatabaseConfiguration valueFromDatabase =
				(from item in target.DatabaseConfigurations
				 where item.PropertyName == propertyName
				 select item).Single();
			Assert.AreEqual(expectedPropertyValue, valueFromDatabase.PropertyValue);
		}

		/// <summary>
		/// A test for Tasks.
		/// </summary>
		[TestMethod()]
		public void TasksTest()
		{
			DataHelper_Accessor dataHelper = new DataHelper_Accessor(new TestsLogHelper());
			dataHelper.UpdateDatabaseSchema();
			Guid expectedTaskId = Guid.NewGuid();
			string expectedTaskName = Guid.NewGuid().ToString();
			using (SqlCeConnection connection = Utils.CreateConnection())
			{
				using (SqlCeCommand command = connection.CreateCommand())
				{
					command.CommandText = string.Format(
						CultureInfo.InvariantCulture,
						"INSERT INTO Task (Id, TaskName, CompletedPercentage, EstimatedTime, CompletedTime, StartDate, DueDate, EndDate, Category) VALUES ('{0}', '{1}', {2}, {2}, {2}, '{3}', '{3}', '{3}', '{1}')",
						expectedTaskId,
						expectedTaskName,
						0,
						DateTime.Today);
					connection.Open();
					command.ExecuteNonQuery();
				}
			}
			TaskPlannerDataContext target = new TaskPlannerDataContext();
			Task taskFromDatabase =
				(from item in target.Tasks
				 where item.Id == expectedTaskId
				 select item).Single();
			Assert.AreEqual(expectedTaskName, taskFromDatabase.TaskName);
		}

		/// <summary>
		/// A test for UsualAvailabilities.
		/// </summary>
		[TestMethod()]
		public void UsualAvailabilitiesTest()
		{
			DataHelper_Accessor dataHelper = new DataHelper_Accessor(new TestsLogHelper());
			dataHelper.UpdateDatabaseSchema();
			string expectedDayOfWeek = Guid.NewGuid().ToString();
			float expectedAvailability = (float)new Random(DateTime.Now.Millisecond).NextDouble();
			using (SqlCeConnection connection = Utils.CreateConnection())
			{
				using (SqlCeCommand command = connection.CreateCommand())
				{
					command.CommandText = string.Format(
						CultureInfo.InvariantCulture,
						"INSERT INTO UsualAvailability (DayOfWeek, Availability) VALUES ('{0}', {1})",
						expectedDayOfWeek,
						expectedAvailability);
					connection.Open();
					command.ExecuteNonQuery();
				}
			}
			TaskPlannerDataContext target = new TaskPlannerDataContext();
			UsualAvailability availabilityFromDatabase =
				(from item in target.UsualAvailabilities
				 where item.DayOfWeek == expectedDayOfWeek
				 select item).Single();
			Assert.AreEqual(expectedAvailability, availabilityFromDatabase.Availability, 0.01);
		}
		#endregion
	}
}
