﻿namespace TaskPlanner.Repository.Test
{
	using System;
	using System.Collections.ObjectModel;
	using System.Globalization;
	using System.IO;
	using System.Linq;
	using Microsoft.VisualStudio.TestTools.UnitTesting;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository;

	/// <summary>
	/// This is a test class for UsualAvailabilityRepositoryTest and is intended
	/// to contain all UsualAvailabilityRepositoryTest Unit Tests.
	/// </summary>
	[TestClass()]
	public class UsualAvailabilityRepositoryTest
	{
		#region Fields
		private TestContext _testContextInstance;
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the test context which provides
		/// information about and functionality for the current test run.
		/// </summary>
		/// <value>The test context.</value>
		public TestContext TestContext
		{
			get
			{
				return _testContextInstance;
			}

			set
			{
				_testContextInstance = value;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Initializes the every test.
		/// </summary>
		[TestInitialize]
		public void InitializeTest()
		{
			if (File.Exists(Utils.DataSource))
			{
				File.Delete(Utils.DataSource);
			}
			DataHelper dataHelper = new DataHelper(new TestsLogHelper());
			dataHelper.EnsureDatabaseHasLatestSchema();
		}

		/// <summary>
		/// A test for UsualAvailabilityRepository Constructor.
		/// </summary>
		[TestMethod()]
		public void UsualAvailabilityRepositoryConstructorTest()
		{
			UsualAvailabilityRepository target = new UsualAvailabilityRepository(); // Just to ensure that there is no exception.
		}

		/// <summary>
		/// A test for GetUsualAvailabilities.
		/// </summary>
		[TestMethod()]
		public void GetUsualAvailabilitiesTest()
		{
			if (File.Exists(Utils.DataSource))
			{
				File.Delete(Utils.DataSource);
			}
			DataHelper_Accessor dataHelper = new DataHelper_Accessor(new TestsLogHelper());
			dataHelper.UpdateDatabaseSchema();
			UsualAvailabilityRepository target = new UsualAvailabilityRepository();
			Collection<UsualAvailability> actual = target.GetUsualAvailabilities();
			int expectedCountOfDaysInWeek = 7;
			Assert.AreEqual(expectedCountOfDaysInWeek, actual.Count);
			DateTimeFormatInfo invariantDateTimeFormat = CultureInfo.InvariantCulture.DateTimeFormat;
			foreach (string nameOfDayOfWeek in invariantDateTimeFormat.DayNames)
			{
				(from item in actual
				 where item.DayOfWeek.Equals(nameOfDayOfWeek, StringComparison.OrdinalIgnoreCase)
				 select item).Single();
			}
		}

		/// <summary>
		/// A test for SetUsualAvailabilities.
		/// </summary>
		[TestMethod()]
		public void SetUsualAvailabilitiesTest()
		{
			UsualAvailabilityRepository target = new UsualAvailabilityRepository();
			Collection<UsualAvailability> expectedUsualAvailabilities = null;
			Utils.AssertException(() => target.SetUsualAvailabilities(expectedUsualAvailabilities), typeof(ArgumentNullException));
			expectedUsualAvailabilities = new Collection<UsualAvailability>();
			UsualAvailability availability = new UsualAvailability();
			availability.DayOfWeek = "1";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			Utils.AssertException(() => target.SetUsualAvailabilities(expectedUsualAvailabilities), typeof(InvalidOperationException));
			availability = new UsualAvailability();
			availability.DayOfWeek = "2";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "3";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "4";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "5";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "6";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "7";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			Utils.AssertException(() => target.SetUsualAvailabilities(expectedUsualAvailabilities), typeof(InvalidOperationException));
			expectedUsualAvailabilities = new Collection<UsualAvailability>();
			availability = new UsualAvailability();
			availability.DayOfWeek = "Monday";
			availability.Availability = 1;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Tuesday";
			availability.Availability = 2;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Wednesday";
			availability.Availability = 3;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Thursday";
			availability.Availability = 4;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Friday";
			availability.Availability = 5.01F;
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Saturday";
			availability.Availability = 6.002F; // Wrong value because epsilon is 0.01
			expectedUsualAvailabilities.Add(availability);
			availability = new UsualAvailability();
			availability.DayOfWeek = "Sunday";
			availability.Availability = 7;
			expectedUsualAvailabilities.Add(availability);
			Utils.AssertException(() => target.SetUsualAvailabilities(expectedUsualAvailabilities), typeof(InvalidOperationException));
			expectedUsualAvailabilities[5].Availability = 6;
			target.SetUsualAvailabilities(expectedUsualAvailabilities);
			Collection<UsualAvailability> actualUsualAvaiabilities = target.GetUsualAvailabilities();
			Assert.AreEqual(expectedUsualAvailabilities.Count, actualUsualAvaiabilities.Count);
			foreach (UsualAvailability expectedUsualAvailability in expectedUsualAvailabilities)
			{
				UsualAvailability actualUsualAvailability =
					(from item in actualUsualAvaiabilities
					 where item.DayOfWeek.Equals(expectedUsualAvailability.DayOfWeek, StringComparison.OrdinalIgnoreCase)
					 select item).Single();
				Assert.AreEqual(expectedUsualAvailability.Availability, actualUsualAvailability.Availability);
			}
		}
		#endregion
	}
}
