﻿namespace TaskPlanner.Repository.Test
{
	using System;
	using System.Configuration;
	using System.Data.EntityClient;
	using System.Data.SqlClient;
	using System.Data.SqlServerCe;
	using Microsoft.VisualStudio.TestTools.UnitTesting;

	/// <summary>
	/// Represents a set of utilities, which can be useful for bunch of tests.
	/// </summary>
	public static class Utils
	{
		#region Properties
		/// <summary>
		/// Gets the data source.
		/// </summary>
		/// <value>The data source.</value>
		public static string DataSource
		{
			get
			{
				using (EntityConnection entityConnection = new EntityConnection(ConfigurationManager.ConnectionStrings["TaskPlannerEntities"].ConnectionString))
				{
					return entityConnection.DataSource;
				}
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Creates the connection.
		/// </summary>
		/// <returns>Sql connection.</returns>
		public static SqlCeConnection CreateConnection()
		{
			SqlConnectionStringBuilder connectionStringBuilder = new SqlConnectionStringBuilder();
			connectionStringBuilder.DataSource = DataSource;
			return new SqlCeConnection(connectionStringBuilder.ConnectionString);
		}

		/// <summary>
		/// Asserts the exception.
		/// </summary>
		/// <param name="action">The action.</param>
		/// <param name="expectedExceptionType">Expected type of the exception.</param>
		public static void AssertException(Action action, Type expectedExceptionType)
		{
			bool exceptionThrown = false;
			try
			{
				action();
			}
			catch (Exception ex)
			{
				exceptionThrown = true;
				Assert.IsInstanceOfType(ex, expectedExceptionType);
			}
			Assert.IsTrue(exceptionThrown);
		}
		#endregion
	}
}
