﻿namespace TaskPlanner.Repository.Model
{
	using System.Data.Objects;
	using TaskPlanner.Entities;

	/// <summary>
	/// Represents the data context.
	/// </summary>
	public class TaskPlannerDataContext : ObjectContext
	{
		#region Fields
		private ObjectSet<Task> _tasks;
		private ObjectSet<DatabaseConfiguration> _databaseConfigurations;
		private ObjectSet<UsualAvailability> _usualAvailabilities;
		private ObjectSet<SpecificAvailability> _specificAvailabilities;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="TaskPlannerDataContext"/> class.
		/// </summary>
		public TaskPlannerDataContext()
			: base("name=TaskPlannerEntities", "TaskPlannerEntities")
		{
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets the tasks.
		/// </summary>
		/// <value>The tasks.</value>
		public ObjectSet<Task> Tasks
		{
			get
			{
				return _tasks ?? (_tasks = CreateObjectSet<Task>());
			}
		}

		/// <summary>
		/// Gets the database configurations.
		/// </summary>
		/// <value>The database configurations.</value>
		public ObjectSet<DatabaseConfiguration> DatabaseConfigurations
		{
			get
			{
				return _databaseConfigurations ?? (_databaseConfigurations = CreateObjectSet<DatabaseConfiguration>());
			}
		}

		/// <summary>
		/// Gets the usual availabilities.
		/// </summary>
		/// <value>The usual availabilities.</value>
		public ObjectSet<UsualAvailability> UsualAvailabilities
		{
			get
			{
				return _usualAvailabilities ?? (_usualAvailabilities = CreateObjectSet<UsualAvailability>());
			}
		}

		/// <summary>
		/// Gets the specific availabilities.
		/// </summary>
		/// <value>The specific availabilities.</value>
		public ObjectSet<SpecificAvailability> SpecificAvailabilities
		{
			get
			{
				return _specificAvailabilities ?? (_specificAvailabilities = CreateObjectSet<SpecificAvailability>());
			}
		}
		#endregion
	}
}
