﻿namespace TaskPlanner.Repository
{
	using System;
	using System.Collections.ObjectModel;
	using System.Linq;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;
	using TaskPlanner.Repository.Model;

	/// <summary>
	/// Represents a repository to manage availability by specific date.
	/// </summary>
	public class SpecificAvailabilityRepository : ISpecificAvailabilityRepository
	{
		#region Methods
		/// <summary>
		/// Gets the availabilities.
		/// </summary>
		/// <param name="startDate">The start date.</param>
		/// <returns>
		/// The list of specific availabilities in specified date range.
		/// </returns>
		public Collection<SpecificAvailability> GetAvailabilities(DateTime startDate)
		{
			using (TaskPlannerDataContext dataContext = new TaskPlannerDataContext())
			{
				return new Collection<SpecificAvailability>(
					(from item in dataContext.SpecificAvailabilities
					 where item.Date >= startDate
					 select item).ToList());
			}
		}

		/// <summary>
		/// Saves the availability.
		/// </summary>
		/// <param name="availability">The availability.</param>
		public void AddAvailability(SpecificAvailability availability)
		{
			if (availability == null)
			{
				throw new ArgumentNullException("availability");
			}
			using (TaskPlannerDataContext dataContext = new TaskPlannerDataContext())
			{
				availability.Date = availability.Date.Date;
				SpecificAvailability existingAvailability =
					(from item in dataContext.SpecificAvailabilities
					 where item.Date == availability.Date
					 select item).SingleOrDefault();
				if (existingAvailability != null)
				{
					existingAvailability.Availability = availability.Availability;
				}
				else
				{
					dataContext.SpecificAvailabilities.AddObject(availability);
				}
				dataContext.SaveChanges();
			}
		}
		#endregion
	}
}
