﻿namespace TaskPlanner.Repository
{
	using System;
	using System.Collections.Generic;
	using System.Collections.ObjectModel;
	using System.Globalization;
	using System.Linq;
	using TaskPlanner.Entities;
	using TaskPlanner.Repository.Interfaces;
	using TaskPlanner.Repository.Model;

	/// <summary>
	/// Represents the repository of usual availability.
	/// </summary>
	public class UsualAvailabilityRepository : IUsualAvailabilityRepository
	{
		#region Methods
		/// <summary>
		/// Gets the usual availabilities.
		/// </summary>
		/// <returns>Usual availabilities by days of week.</returns>
		public Collection<UsualAvailability> GetUsualAvailabilities()
		{
			using (TaskPlannerDataContext dataContext = new TaskPlannerDataContext())
			{
				return new Collection<UsualAvailability>(dataContext.UsualAvailabilities.ToList());
			}
		}

		/// <summary>
		/// Sets the usual availabilities.
		/// </summary>
		/// <param name="usualAvailabilities">The usual availabilities by days of week.</param>
		public void SetUsualAvailabilities(Collection<UsualAvailability> usualAvailabilities)
		{
			if (usualAvailabilities == null)
			{
				throw new ArgumentNullException("usualAvailabilities");
			}
			List<string> dayNames = new List<string>(CultureInfo.InvariantCulture.DateTimeFormat.DayNames);
			if (usualAvailabilities.Count != dayNames.Count)
			{
				throw new InvalidOperationException("Count of availabilities should be equal count of days in week.");
			}
			using (TaskPlannerDataContext dataContext = new TaskPlannerDataContext())
			{
				foreach (UsualAvailability usualAvailability in usualAvailabilities)
				{
					if (!dayNames.Contains(usualAvailability.DayOfWeek, StringComparer.OrdinalIgnoreCase))
					{
						throw new InvalidOperationException("Name of days should be equal to name of days in invariant culture.");
					}
					if (!float.Equals((float)Math.Floor(usualAvailability.Availability * 100) / 100, usualAvailability.Availability))
					{
						throw new InvalidOperationException("There is should not be more than 2 numbers after decimal point.");
					}
					UsualAvailability existingAvailability =
						(from item in dataContext.UsualAvailabilities
						 where item.DayOfWeek == usualAvailability.DayOfWeek
						 select item).Single();
					existingAvailability.Availability = usualAvailability.Availability;
				}
				dataContext.SaveChanges();
			}
		}
		#endregion
	}
}
