﻿namespace TaskPlanner.Shell
{
	using System;
	using Microsoft.Practices.EnterpriseLibrary.Common.Configuration.Unity;
	using Microsoft.Practices.Unity.InterceptionExtension;
	using TaskPlanner.BusinessLogic;
	using TaskPlanner.BusinessLogic.Interfaces;
	using TaskPlanner.Core;
	using TaskPlanner.Repository;
	using TaskPlanner.Repository.Interfaces;

	/// <summary>
	/// The application bootstrapper.
	/// </summary>
	public static class ApplicationBootstrapper
	{
		#region Methods
		/// <summary>
		/// Initializes this instance.
		/// </summary>
		public static void Initialize()
		{
			ConfigureServicesLocator();
		}

		/// <summary>
		/// Configures the services locator.
		/// </summary>
		private static void ConfigureServicesLocator()
		{
			ServiceLocator.Instance.AddExtension(new EnterpriseLibraryCoreExtension());
			ServiceLocator.Instance.AddExtension(new Interception());
			RegisterType(typeof(ILogHelper), typeof(LogHelper));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(IDataHelper), typeof(DataHelper));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(ITaskRepository), typeof(TaskRepository));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(ICategoryRepository), typeof(CategoryRepository));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(IUsualAvailabilityRepository), typeof(UsualAvailabilityRepository));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(ISpecificAvailabilityRepository), typeof(SpecificAvailabilityRepository));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(IDatabaseManager), typeof(DatabaseManager));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(ICategoryManager), typeof(CategoryManager));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(ITaskManager), typeof(TaskManager));
			RegisterTypeWithLoggingAndExceptionHandling(typeof(IAvailabilityManager), typeof(AvailabilityManager));
		}

		/// <summary>
		/// Registers the type.
		/// </summary>
		/// <param name="baseType">The base type.</param>
		/// <param name="implementation">The implementation of the base type.</param>
		private static void RegisterType(Type baseType, Type implementation)
		{
			ServiceLocator.Instance.RegisterType(baseType, implementation);
		}

		/// <summary>
		/// Registers the type with logging and exception handling.
		/// </summary>
		/// <param name="baseType">The base type.</param>
		/// <param name="implementation">The implementation of the base type.</param>
		private static void RegisterTypeWithLoggingAndExceptionHandling(Type baseType, Type implementation)
		{
			ServiceLocator.Instance.RegisterType(
				baseType,
				implementation,
				new Interceptor<InterfaceInterceptor>(),
				new InterceptionBehavior<ExceptionHandlingBehavior>(),
				new InterceptionBehavior<LoggingBehavior>());
		}
		#endregion
	}
}
