﻿namespace TaskPlanner.Controls
{
	using System.Collections;
	using System.Collections.Generic;
	using System.Windows;
	using System.Windows.Controls;

	/// <summary>
	/// Interaction logic for ComboBoxWithLabel.xaml.
	/// </summary>
	public partial class ComboBoxWithLabel : UserControl
	{
		#region Fields
		public static readonly DependencyProperty ComboBoxSelectedItemProperty =
			DependencyProperty.Register("ComboBoxSelectedItem", typeof(object), typeof(ComboBoxWithLabel), new UIPropertyMetadata(null));

		public static readonly DependencyProperty ComboBoxItemsProperty =
			DependencyProperty.Register("ComboBoxItems", typeof(IList), typeof(ComboBoxWithLabel), new UIPropertyMetadata(null));

		public static readonly DependencyProperty ComboBoxTextProperty =
			DependencyProperty.Register("ComboBoxText", typeof(string), typeof(ComboBoxWithLabel), new UIPropertyMetadata(string.Empty));
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="ComboBoxWithLabel"/> class.
		/// </summary>
		public ComboBoxWithLabel()
		{
			InitializeComponent();
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the label text.
		/// </summary>
		/// <value>The label text.</value>
		public string LabelText
		{
			get
			{
				return Label.Text;
			}

			set
			{
				Label.Text = value;
			}
		}

		/// <summary>
		/// Gets or sets the combo box selected item.
		/// </summary>
		/// <value>The combo box selected item.</value>
		public object ComboBoxSelectedItem
		{
			get
			{
				return GetValue(ComboBoxSelectedItemProperty);
			}

			set
			{
				SetValue(ComboBoxSelectedItemProperty, value);
			}
		}

		/// <summary>
		/// Gets or sets the combo box items.
		/// </summary>
		/// <value>The combo box items.</value>
		public List<object> ComboBoxItems
		{
			get
			{
				return (List<object>)GetValue(ComboBoxItemsProperty);
			}

			set
			{
				SetValue(ComboBoxItemsProperty, value);
			}
		}

		/// <summary>
		/// Gets or sets the combo box text.
		/// </summary>
		/// <value>The combo box text.</value>
		public string ComboBoxText
		{
			get
			{
				return (string)GetValue(ComboBoxTextProperty);
			}

			set
			{
				SetValue(ComboBoxTextProperty, value);
			}
		}

		/// <summary>
		/// Gets or sets a value indicating whether this instance is combo box editable.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if this instance is combo box editable; otherwise, <c>false</c>.
		/// </value>
		public bool IsComboBoxEditable
		{
			get
			{
				return ComboBox.IsEditable;
			}

			set
			{
				ComboBox.IsEditable = value;
			}
		}
		#endregion
	}
}
