﻿namespace TaskPlanner.Controls
{
	using System.Windows;
	using System.Windows.Controls;

	/// <summary>
	/// Interaction logic for TextBoxWithLabel.xaml.
	/// </summary>
	public partial class TextBoxWithLabel : UserControl
	{
		#region Fields
		public static readonly DependencyProperty TextBoxTextProperty =
			DependencyProperty.Register("TextBoxText", typeof(string), typeof(TextBoxWithLabel), new UIPropertyMetadata(string.Empty));

		public static readonly DependencyProperty LabelTextProperty =
			DependencyProperty.Register("LabelText", typeof(string), typeof(TextBoxWithLabel), new UIPropertyMetadata(string.Empty));
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="TextBoxWithLabel"/> class.
		/// </summary>
		public TextBoxWithLabel()
		{
			InitializeComponent();
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the label text.
		/// </summary>
		/// <value>The label text.</value>
		public string LabelText
		{
			get
			{
				return (string)GetValue(LabelTextProperty);
			}

			set
			{
				SetValue(LabelTextProperty, value);
			}
		}

		/// <summary>
		/// Gets or sets the text box text.
		/// </summary>
		/// <value>The text box text.</value>
		public string TextBoxText
		{
			get
			{
				return (string)GetValue(TextBoxTextProperty);
			}

			set
			{
				SetValue(TextBoxTextProperty, value);
			}
		}
		#endregion
	}
}
