﻿namespace TaskPlanner.ValidationRules
{
	using System.Globalization;
	using System.Windows.Controls;
	using TaskPlanner.Properties;

	/// <summary>
	/// Validates whether value can be converted to single.
	/// </summary>
	public class SingleValueValidationRule : ValidationRule
	{
		#region Methods
		/// <summary>
		/// When overridden in a derived class, performs validation checks on a value.
		/// </summary>
		/// <param name="value">The value from the binding target to check.</param>
		/// <param name="cultureInfo">The culture to use in this rule.</param>
		/// <returns>
		/// A <see cref="T:System.Windows.Controls.ValidationResult"/> object.
		/// </returns>
		public override ValidationResult Validate(object value, CultureInfo cultureInfo)
		{
			ValidationResult result = ValidationResult.ValidResult;
			float convertedValue;
			string originalValue = value as string;
			if (!float.TryParse(originalValue, NumberStyles.Float, cultureInfo, out convertedValue))
			{
				result = new ValidationResult(false, Resources.ValueShouldBeASingle);
			}
			return result;
		}
		#endregion
	}
}
