﻿namespace TaskPlanner.ViewModels
{
	using System;
	using System.Collections.Generic;
	using TaskPlanner.Entities;

	/// <summary>
	/// Represents a view model for list of specific avaiabilities.
	/// </summary>
	public class SpecificAvailabilityListViewModel : ViewModelBase
	{
		#region Fields
		private IEnumerable<SpecificAvailability> _specificAvailabilities;
		#endregion

		#region Constructor
		/// <summary>
		/// Initializes a new instance of the <see cref="SpecificAvailabilityListViewModel"/> class.
		/// </summary>
		/// <param name="specificAvailabilities">The specific availabilities.</param>
		public SpecificAvailabilityListViewModel(IEnumerable<SpecificAvailability> specificAvailabilities)
		{
			if (specificAvailabilities == null)
			{
				throw new ArgumentNullException("specificAvailabilities");
			}
			_specificAvailabilities = specificAvailabilities;
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets the specific availabilities view models.
		/// </summary>
		/// <value>The specific availabilities view models.</value>
		public IEnumerable<SpecificAvailabilityViewModel> Items
		{
			get
			{
				foreach (SpecificAvailability specificAvailability in _specificAvailabilities)
				{
					yield return new SpecificAvailabilityViewModel(specificAvailability);
				}
			}
		}
		#endregion
	}
}
