﻿namespace TaskPlanner.ViewModels
{
	using System;
	using TaskPlanner.Entities;

	/// <summary>
	/// Represents a view model for specific availability.
	/// </summary>
	public class SpecificAvailabilityViewModel : ViewModelBase
	{
		#region Fields
		private SpecificAvailability _model;
		private bool _isDateSet;
		private bool _isAvailabilitySet;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="SpecificAvailabilityViewModel"/> class.
		/// </summary>
		/// <param name="model">The model.</param>
		/// <param name="isNew">If set to <c>true</c> the model is a new item.</param>
		public SpecificAvailabilityViewModel(SpecificAvailability model, bool isNew)
		{
			if (model == null)
			{
				throw new ArgumentNullException("model");
			}
			_model = model;
			if (!isNew)
			{
				_isDateSet = true;
				_isAvailabilitySet = true;
			}
		}

		/// <summary>
		/// Initializes a new instance of the <see cref="SpecificAvailabilityViewModel"/> class.
		/// </summary>
		/// <param name="model">The model.</param>
		public SpecificAvailabilityViewModel(SpecificAvailability model)
			: this(model, false)
		{
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets or sets the date.
		/// </summary>
		/// <value>The date of the availability.</value>
		public DateTime? Date
		{
			get
			{
				return _isDateSet ? (DateTime?)_model.Date : null;
			}

			set
			{
				if (value.HasValue)
				{
					_model.Date = value.Value;
					_isDateSet = true;
				}
				else
				{
					_isDateSet = false;
				}
			}
		}

		/// <summary>
		/// Gets or sets the availability.
		/// </summary>
		/// <value>The availability.</value>
		public float? Availability
		{
			get
			{
				return _isAvailabilitySet ? (float?)_model.Availability : null;
			}

			set
			{
				if (value.HasValue)
				{
					_model.Availability = value.Value;
					_isAvailabilitySet = true;
				}
				else
				{
					_isAvailabilitySet = false;
				}
			}
		}

		/// <summary>
		/// Gets a value indicating whether availability is set.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if availability is set; otherwise, <c>false</c>.
		/// </value>
		public bool IsAvailabilitySet
		{
			get
			{
				return _isAvailabilitySet;
			}
		}

		/// <summary>
		/// Gets a value indicating whether date is set.
		/// </summary>
		/// <value>
		/// 	<c>True</c> if date is set; otherwise, <c>false</c>.
		/// </value>
		public bool IsDateSet
		{
			get
			{
				return _isDateSet;
			}
		}

		/// <summary>
		/// Gets the model.
		/// </summary>
		/// <value>The model.</value>
		internal SpecificAvailability Model
		{
			get
			{
				return _model;
			}
		}
		#endregion
	}
}
