﻿namespace TaskPlanner.ViewModels
{
	using System.Windows.Input;
	using TaskPlanner.BusinessLogic.Interfaces;

	/// <summary>
	/// Represents a view model for the workload view.
	/// </summary>
	public class WorkloadViewModel : ViewModelBase
	{
		#region Fields
		private ICommand _editAvailabilityCommand;
		private IAvailabilityManager _availabilityManager;
		private ITaskManager _taskManager;
		private ICategoryManager _categoryManager;
		#endregion

		#region Constructors
		/// <summary>
		/// Initializes a new instance of the <see cref="WorkloadViewModel"/> class.
		/// </summary>
		/// <param name="availabilityManager">The availability manager.</param>
		/// <param name="taskManager">The task manager.</param>
		/// <param name="categoryManager">The category manager.</param>
		public WorkloadViewModel(
			IAvailabilityManager availabilityManager,
			ITaskManager taskManager,
			ICategoryManager categoryManager)
		{
			_availabilityManager = availabilityManager;
			_taskManager = taskManager;
			_categoryManager = categoryManager;
		}
		#endregion

		#region Properties
		/// <summary>
		/// Gets the edit availability command.
		/// </summary>
		/// <value>The edit availability command.</value>
		public ICommand EditAvailabilityCommand
		{
			get
			{
				if (_editAvailabilityCommand == null)
				{
					_editAvailabilityCommand = new Command(parameter => EditAvailability());
				}
				return _editAvailabilityCommand;
			}
		}
		#endregion

		#region Methods
		/// <summary>
		/// Edits the availability.
		/// </summary>
		public void EditAvailability()
		{
			EditAvailability view = new EditAvailability();
			EditAvailabilityViewModel viewModel = new EditAvailabilityViewModel(_availabilityManager, _taskManager, _categoryManager);
			viewModel.Closing += (sender, e) => view.Close();
			view.DataContext = viewModel;
			view.ShowDialog();
		}
		#endregion
	}
}
